==> sources_fancymenu_fabric_3.8.0_MC_1.19.2.jar: de/keksuccino/fancymenu/mixin/mixins/common/client/MixinProgressScreen.java <==
package de.keksuccino.fancymenu.mixin.mixins.common.client;

import com.llamalad7.mixinextras.injector.WrapWithCondition;
import de.keksuccino.fancymenu.customization.ScreenCustomization;
import de.keksuccino.fancymenu.util.rendering.ui.screen.WidgetifiedScreen;
import de.keksuccino.fancymenu.util.rendering.ui.widget.TextWidget;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import java.util.Objects;
import net.minecraft.class_2561;
import net.minecraft.class_327;
import net.minecraft.class_435;
import net.minecraft.class_437;
import net.minecraft.class_4587;

@WidgetifiedScreen
@Mixin(class_435.class)
public class MixinProgressScreen extends class_437 {

    @Shadow private @Nullable class_2561 header;
    @Shadow private @Nullable class_2561 stage;
    @Shadow private int progress;

    @Unique private TextWidget headerTextFancyMenu;
    @Unique private TextWidget stageTextFancyMenu;

    protected MixinProgressScreen(class_2561 $$0) {
        super($$0);
    }

    @Override
    protected void method_25426() {

        if (this.isCustomizableFancyMenu()) {

            this.headerTextFancyMenu = this.method_37063(TextWidget.empty(0, 70, 500))
                    .setTextAlignment(TextWidget.TextAlignment.CENTER)
                    .centerWidget(this)
                    .setWidgetIdentifierFancyMenu("header");

            this.stageTextFancyMenu = this.method_37063(TextWidget.empty(0, 90, 500))
                    .setTextAlignment(TextWidget.TextAlignment.CENTER)
                    .centerWidget(this)
                    .setWidgetIdentifierFancyMenu("stage");

            this.updateText();

        }

    }
    @Unique
    private void updateText() {

        if (this.headerTextFancyMenu != null) {
            this.headerTextFancyMenu.method_25355(Objects.requireNonNullElse(this.header, class_2561.method_43473()));
        }

        if (this.stageTextFancyMenu != null) {
            if ((this.stage != null) && (this.progress != 0)) {
                this.stageTextFancyMenu.method_25355(class_2561.method_43473().method_10852(this.stage).method_27693(" " + this.progress + "%"));
            } else {
                this.stageTextFancyMenu.method_25355(class_2561.method_43473());
            }
        }

    }

    @WrapWithCondition(method = "render", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/screens/ProgressScreen;drawCenteredString(Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/gui/Font;Lnet/minecraft/network/chat/Component;III)V"))
    private boolean wrapDrawCenteredStringInRenderFancyMenu(class_4587 poseStack, class_327 font, class_2561 component, int i1, int i2, int i3) {
        return !this.isCustomizableFancyMenu();
    }

    @Inject(method = "progressStart", at = @At("RETURN"))
    private void onProgressStartFancyMenu(class_2561 component, CallbackInfo info) {
        this.updateText();
    }

    @Inject(method = "progressStage", at = @At("RETURN"))
    private void onProgressStageFancyMenu(class_2561 component, CallbackInfo info) {
        this.updateText();
    }

    @Inject(method = "progressStagePercentage", at = @At("RETURN"))
    private void onProgressStagePercentageFancyMenu(int percentage, CallbackInfo info) {
        this.updateText();
    }

    @Unique
    private boolean isCustomizableFancyMenu() {
        return ScreenCustomization.isCustomizationEnabledForScreen(this);
    }

}

==> sources_fancymenu_fabric_3.8.1_MC_1.21.10.jar: de/keksuccino/fancymenu/mixin/mixins/common/client/MixinProgressScreen.java <==
package de.keksuccino.fancymenu.mixin.mixins.common.client;

import com.llamalad7.mixinextras.injector.WrapWithCondition;
import de.keksuccino.fancymenu.customization.ScreenCustomization;
import de.keksuccino.fancymenu.util.rendering.ui.screen.WidgetifiedScreen;
import de.keksuccino.fancymenu.util.rendering.ui.widget.TextWidget;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import java.util.Objects;
import net.minecraft.class_2561;
import net.minecraft.class_327;
import net.minecraft.class_332;
import net.minecraft.class_435;
import net.minecraft.class_437;

@WidgetifiedScreen
@Mixin(class_435.class)
public class MixinProgressScreen extends class_437 {

    @Shadow private @Nullable class_2561 header;
    @Shadow private @Nullable class_2561 stage;
    @Shadow private int progress;

    @Unique private TextWidget headerTextFancyMenu;
    @Unique private TextWidget stageTextFancyMenu;

    protected MixinProgressScreen(class_2561 $$0) {
        super($$0);
    }

    @Override
    protected void method_25426() {

        if (this.isCustomizableFancyMenu()) {

            this.headerTextFancyMenu = this.method_37063(TextWidget.empty(0, 70, 500))
                    .setTextAlignment(TextWidget.TextAlignment.CENTER)
                    .centerWidget(this)
                    .setWidgetIdentifierFancyMenu("header");

            this.stageTextFancyMenu = this.method_37063(TextWidget.empty(0, 90, 500))
                    .setTextAlignment(TextWidget.TextAlignment.CENTER)
                    .centerWidget(this)
                    .setWidgetIdentifierFancyMenu("stage");

            this.updateText();

        }

    }
    @Unique
    private void updateText() {

        if (this.headerTextFancyMenu != null) {
            this.headerTextFancyMenu.method_25355(Objects.requireNonNullElse(this.header, class_2561.method_43473()));
        }

        if (this.stageTextFancyMenu != null) {
            if ((this.stage != null) && (this.progress != 0)) {
                this.stageTextFancyMenu.method_25355(class_2561.method_43473().method_10852(this.stage).method_27693(" " + this.progress + "%"));
            } else {
                this.stageTextFancyMenu.method_25355(class_2561.method_43473());
            }
        }

    }

    @WrapWithCondition(method = "render", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/GuiGraphics;drawCenteredString(Lnet/minecraft/client/gui/Font;Lnet/minecraft/network/chat/Component;III)V"))
    private boolean wrapDrawCenteredStringInRenderFancyMenu(class_332 instance, class_327 $$0, class_2561 $$1, int $$2, int $$3, int $$4) {
        return !this.isCustomizableFancyMenu();
    }

    @Inject(method = "progressStart", at = @At("RETURN"))
    private void onProgressStartFancyMenu(class_2561 component, CallbackInfo info) {
        this.updateText();
    }

    @Inject(method = "progressStage", at = @At("RETURN"))
    private void onProgressStageFancyMenu(class_2561 component, CallbackInfo info) {
        this.updateText();
    }

    @Inject(method = "progressStagePercentage", at = @At("RETURN"))
    private void onProgressStagePercentageFancyMenu(int percentage, CallbackInfo info) {
        this.updateText();
    }

    @Unique
    private boolean isCustomizableFancyMenu() {
        return ScreenCustomization.isCustomizationEnabledForScreen(this);
    }

}
